@@ -54,8 +54,10 @@
 ;; Arrays
 (test-equal #() (json-string->scm "[]"))
 (test-equal #(1 2 3 4) (json-string->scm "[1,2,3,4]"))
+(test-equal #(1 2 3 4) (json-string->scm "[   1,2, 3,4  ]"))
 (test-equal #(1 2 #(3 4) #(5 6 #(7 8))) (json-string->scm "[1,2,[3,4],[5,6,[7,8]]]" ))
 (test-equal #(1 "two" 3 "four") (json-string->scm "[1,\"two\",3,\"four\"]"))
+(test-error #t (json-string->scm "[1,2,,,5]"))
 
 ;; Objects
 (test-equal '(("foo" . "bar")) (json-string->scm "{\"foo\":\"bar\"}"))
